@@ -473,7 +473,10 @@ def main():
         if sast_len > 1: ## if the mentioned languages are more than one
             logging.info('Detected Languges %s',Config.sast_lang)
             for lang in Config.sast_lang:
-                loc = Utils.getLoc(Config.sast_build_dir, lang)
+                try:   
+                    loc = Utils.getLoc(Config.sast_build_dir, lang)
+                except:
+                    loc = 0    
                 #print(loc)
                 logging.info('Running scanner with language: %s',lang)
 
